---

slug: /spatial-data-type-overview
---

# Overview of spatial data types

The Geographic Information System (GIS) feature of seekdb includes the following spatial data types:

* `GEOMETRY`

* `POINT`

* `LINESTRING`

* `POLYGON`

* `MULTIPOINT`

* `MULTILINESTRING`

* `MULTIPOLYGON`

* `GEOMETRYCOLLECTION`

Among these, `POINT`, `LINESTRING`, and `POLYGON` are the three most fundamental types, used to store individual spatial data. They respectively extend into three collection types: `MULTIPOINT`, `MULTILINESTRING`, and `MULTIPOLYGON`, which are used to store collections of spatial data but can only represent collections of their respective specified base types. `GEOMETRY` is an abstract type that can represent any base type, and `GEOMETRYCOLLECTION` can be a collection of any `GEOMETRY` types.